package model

import (
	"time"

	"go.mongodb.org/mongo-driver/bson/primitive"
)

// 生产计划
type ProductPlan struct {
	Id   primitive.ObjectID `bson:"_id,omitempty" json:"_id"`
	Pack *Pack              `bson:"pack,omitempty" json:"pack"`

	Thumbnail  string
	Name       string
	CreateUser string
	//生产数量
	Total int

	//状态
	State string

	//总价
	TotalPrice float64

	UpdateTime time.Time
	CreateTime time.Time

	//所有包装部件的工序
	Components []*PackComp
}

type PackComp struct {
	Id    primitive.ObjectID //包装部件I
	Steps []*ProductUnit     //生产的工序列表
}

// 工序单位
type ProductUnit struct {
	Id     string //工序Id
	Type   string //mat craft process
	TypeId string //type类型对应的Id

	CraftNorm  *CraftNorm //生产工艺的规格要求
	MatNorm    *MatNorm
	PlanCount  float64 //生产数量
	FinalCount float64 //最终数量

	TotalPrice   float64   //总价
	DeliveryTime time.Time //交货时间

	Price float64 //单价

	//供应商
	SupplierId primitive.ObjectID

	//计价
	PriceStrategy *PriceStrategy

	//单据Id
	BillId primitive.ObjectID
}

type MatNorm struct {
	PaperWidth  string //下纸尺寸
	PaperHeight string //下纸尺寸
}

type CraftNorm struct {
	PrintWidth string //印刷尺寸
	PrintHeigt string //印刷尺寸
}

type ProcessNorm struct {
	Norm string
}
